@@ -5,6 +5,8 @@
 from importlib import import_module
 
 from scrapy import signals
+from selenium import webdriver
+from selenium_stealth import stealth
 from scrapy.http import HtmlResponse
 from scrapy.exceptions import NotConfigured
 from selenium.webdriver.common.by import By
@@ -15,7 +17,7 @@ from selenium.webdriver.support import expected_conditions as EC
 class SeleniumDownloaderMiddleware:
     """Scrapy middleware handling the requests using selenium"""
 
-    def __init__(self, driver_name, driver_executable_path, driver_arguments,
+    def __init__(self, platform, driver_executable_path, driver_arguments,
                  browser_executable_path):
         """Initialize the selenium webdriver
 
@@ -31,43 +33,43 @@ class SeleniumDownloaderMiddleware:
             The path of the executable binary of the browser
         """
 
-        webdriver_base_path = f'selenium.webdriver.{driver_name}'
-
-        driver_klass_module = import_module(f'{webdriver_base_path}.webdriver')
-        driver_klass = getattr(driver_klass_module, 'WebDriver')
-
-        driver_options_module = import_module(f'{webdriver_base_path}.options')
-        driver_options_klass = getattr(driver_options_module, 'Options')
-
-        driver_options = driver_options_klass()
+        driver_options = webdriver.ChromeOptions()
         if browser_executable_path:
             driver_options.binary_location = browser_executable_path
+        driver_options.add_argument("--headless")
+        driver_options.add_argument("start-maximized")
+        driver_options.add_experimental_option("excludeSwitches", ["enable-automation"])
+        driver_options.add_experimental_option('useAutomationExtension', False)
         for argument in driver_arguments:
             driver_options.add_argument(argument)
 
-        driver_kwargs = {
-            'executable_path': driver_executable_path,
-            f'{driver_name}_options': driver_options
-        }
+        self.driver = webdriver.Chrome(options=driver_options, executable_path=driver_executable_path)
 
-        self.driver = driver_klass(**driver_kwargs)
+        stealth(self.driver,
+                languages=["en-US", "en"],
+                vendor="Google Inc.",
+                platform=platform,
+                webgl_vendor="Intel Inc.",
+                renderer="Intel Iris OpenGL Engine",
+                fix_hairline=True,
+                )
 
     @classmethod
     def from_crawler(cls, crawler):
         """Initialize the middleware with the crawler settings"""
 
-        driver_name = crawler.settings.get('SELENIUM_DRIVER_NAME')
+        platform = crawler.settings.get('PLATFORM')
         driver_executable_path = crawler.settings.get('SELENIUM_DRIVER_EXECUTABLE_PATH')
         browser_executable_path = crawler.settings.get('SELENIUM_BROWSER_EXECUTABLE_PATH')
         driver_arguments = crawler.settings.get('SELENIUM_DRIVER_ARGUMENTS')
 
-        if not driver_name or not driver_executable_path:
+        if not platform or not driver_executable_path:
             raise NotConfigured(
                 'SELENIUM_DRIVER_NAME and SELENIUM_DRIVER_EXECUTABLE_PATH must be set'
             )
 
         middleware = cls(
-            driver_name=driver_name,
+            platform=platform,
             driver_executable_path=driver_executable_path,
             driver_arguments=driver_arguments,
             browser_executable_path=browser_executable_path
